import { Program } from 'typescript';
import { Pipe } from '@angular/core';
import { StaticSymbol, PipeResolver, CompileNgModuleMetadata } from '@angular/compiler';
import { ContextSymbols } from './context-symbols';
import { Symbol } from './symbol';
/**
 * A wrapper around the pipe symbol.
 *
 * @export
 * @class PipeSymbol
 * @extends {Symbol}
 */
export declare class PipeSymbol extends Symbol {
    private resolver;
    private projectSymbols;
    /**
     * Creates an instance of PipeSymbol.
     *
     * @param {Program} program
     * @param {StaticSymbol} symbol
     * @param {PipeResolver} resolver
     * @param {ContextSymbols} projectSymbols
     *
     * @memberOf PipeSymbol
     */
    constructor(program: Program, symbol: StaticSymbol, resolver: PipeResolver, projectSymbols: ContextSymbols);
    /**
     * Returns the module where the wrapped pipe was defined.
     *
     * @returns {(CompileNgModuleMetadata | undefined)}
     *
     * @memberOf PipeSymbol
     */
    getModule(): CompileNgModuleMetadata | undefined;
    /**
     * Returns the pipe metadata.
     *
     * @returns {Pipe}
     *
     * @memberOf PipeSymbol
     */
    getMetadata(): Pipe;
}
